##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-ALGORITHM-KMEANS
##
##################################################################################

clusterkmeans <- function(dataset,
                          clusters,
                          repeats)
{
  clusterlist <- list()
  
  cat("Clustering the dataset.\n")
  
  for (j in 1:repeats)
    {
      
      c <- cclust(dataset, clusters)
      clusterlist <- c(clusterlist, split(seq(1:dim(dataset)[1]),
                                           as.factor(c$cluster)))
      
      cat(round(j/repeats,2)*100,"% finished...\n")
    }
            
  clusterlist
}

##################################################################################
##
## CLASS CLUSTER-ALGORITHM-KMEANS
##
##################################################################################

setClass("clusterAlgorithmKmeans",
         representation(
                        repeats  = "numeric",
                        clusters = "numeric"
                        ),
         prototype(repeats = 100,
                   clusters = 100,
                   config = list(
                     repeats =
                     function (object)
                     {
                       selectNumber(paste("Please select how often the K-Means\n",
                                          "clustering should be repeated.\n", sep = ""), 2, 1000)
                     },
                     clusters =
                     function (object)
                     {
                       selectNumber(paste("Please select the number of clusters\n",
                                          "for the K-means clustering.", sep =""), 2, 10000)
                     }
                     ),
                   setup = list(
                     repeats =
                     function (X, object)
                     {
                       if (as.integer(X) == 0)
                         stop("The \"repeats\" value is missing! You should set how often the clustering should be repeated!")
                     },
                     clusters =
                     function (X, object)
                     {
                       if (as.integer(X) == 0)
                         stop("The \"clusters\" value is missing! Please specify the number of clusters the dataset should be partitioned into!")
                     }
                     ),
                   execute = function(object, parent)
                   {
                     if (checkData(object@clusterset, "clustered", "execute", TRUE)) return
            
                     ## Requirement for Kmeans
                     if (!require(cclust)) stop("Please install the package cclust for the k-means function!")
                     
                     if (is.null(parent))
                       stop("The object needs to have a defined parent before it can be used!")
                     
                     object@clusterset <- clusterkmeans(exprs(parent@data@dataset),
                                                        object@clusters,
                                                        object@repeats)
                     object
                   }                     
                   ),
         contains = "clusterAlgorithm"
         )

setMethod("print", "clusterAlgorithmKmeans", function(x, ...)
          {
            printData("Algorithm",
                      "Kmeans",
                      c(paste("Number of repeats:", x@repeats),
                        paste("Number of clusters:", x@clusters),
                        ifelse(length(x@clusterset)!=0, "The dataset has been clustered.", "The object holds no result yet.")))
          }
          )
