##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-ALGORITHM-PAM
##
##################################################################################

clusterpam <- function(dataset,
                       clusters,
                       distance = "euclidian")
{
  c <- pam(dataset,
           clusters,
           cluster.only = TRUE,
           metric = distance)

  split(seq(1:dim(dataset)[1]),
      as.factor(c))
}

##################################################################################
##
## CLASS CLUSTER-ALGORITHM-PAM
##
##################################################################################

setClass("clusterAlgorithmPam",
         representation(
                        distance = "character",
                        clusters = "numeric"
                        ),
         prototype(distance = "euclidian",
                   clusters = 50,
                   config = list(
                     distance =
                     function (object)
                     {
                       selectOption(c("euclidean", "manhattan"),
                                    paste("Please select the distance measure to be\n",
                                          "used. See the PAM documentation for a detailed\n",
                                          "explanation (?pam).", sep ="")
                                    )
                     },
                     clusters =
                     function (object)
                     {
                       selectNumber(paste("Please select the number of clusters\n",
                                          "for the PAM clustering.", sep =""), 2, 10000)
                     }
                     ),
                   setup = list(
                     distance =
                     function (X, object)
                     {
                       if (length(X %in% c("euclidean", "manhattan")) == 0)
                         stop("The distance matrix for pam has to be either \"euclidian\" or \"manhattan\"!")
                     },
                     clusters =
                     function (X, object)
                     {
                       if (as.integer(X) == 0)
                         stop("The \"clusters\" value is missing! Please specify the number of clusters the dataset should be partitioned into!")
                     }
                     ),
                   execute = function(object, parent)
                   {
                     if (checkData(object@clusterset, "clustered", "execute", TRUE)) return
                     
                     ## Requirement for Pam
                     if (!require(cluster)) stop("Please install the package cluster for the pam function!")
                     
                     if (is.null(parent))
                       stop("The object needs to have a defined parent before it can be used!")
                     
                     cat("Clustering the dataset.\n")

                     object@clusterset <- clusterpam(exprs(parent@data@dataset),
                                                     object@clusters,
                                                     object@distance)
                     
                     cat("Finished...\n")

                     object
                   }
                   ),
         contains = "clusterAlgorithm"
         )

setMethod("print", "clusterAlgorithmPam", function(x, ...)
          {
            printData("Algorithm",
                      "Pam",
                      c(paste("Distance measure:", x@distance),
                        paste("Number of clusters:", x@clusters),
                        ifelse(length(x@clusterset)!=0, "The dataset has been clustered.", "The object holds no result yet.")))
          }
          )

