##################################################################################
##
## CLASS CLUSTER-ANNOTATION-LOOKUP
##
##################################################################################

setClass("clusterAnnotationLookup",
         representation(uniqueid   = "character",
                        ## The path to the lookup table
                        lookup     = "character"
                        ),
         prototype(config = list(
                     lookup =
                     function (object)
                     {
                       selectCore(paste("Please specify the path to your lookup table.\n",
                                        "This file should have the common csv format.\n",
                                        "It must have a header with the column name\n",
                                        "and the values are seperated by \",\"\n",
                                        "It may only have two columns. The first \n",
                                        "column specifies the locus link ID, the \n",
                                        "second column represents the matching gene ID.\n",
                                        "Please ensure that the gene ID's do match exactly\n",
                                        "to the rownames in your dataset.", sep =""),
                                  )
                       
                     },
                     ),
                   setup = list(
                     lookup = 
                     function(X, object)
                     {
                       # FIXME: Bad check. Should check for file existence
                       if (!is.character(X) || !length(X) > 0)
                         stop("The file path should be a string!")
                     },
                     ),
                   execute = function(object, parent)
                   {
                    
                     object@uniqueid <- parent@data@uniqueid


                     locus <- read.csv(object@lookup)
                     
                     if (!require(GO))
                       stop("Please install the GO package to be able to parse the GO annotation!")

                     ## Map the locus link id to GO entries. Mark non existant entries NA
                     ll2go <- mget(as.character(locus[,1]),envir=GOLOCUSID2GO,ifnotfound=NA)

                     ## Gene id's from the annotation table
                     gidlist <- locus[,2]

                     ## remove all entries that do not map to a GO entry
                     reducedGID <- gidlist[!is.na(ll2go)]
                     reducedL2G <- ll2go[!is.na(ll2go)]
                     
                     go2all <- NULL

                     for (i in 1:length(reducedGID)) {
                       
                       x <- as.character(reducedGID[i])
                       y <- names(reducedL2G[[i]])
                       
                       if (is.null(go2all)) {
                         go2all <- cbind(y, rep(x, length(y)))
                       } else {
                         go2all <- rbind(go2all, cbind(y, rep(x, length(y))))
                       }
                     }

                     ## remove duplicate entries
                     go2alltable <- go2all[!duplicated(paste(go2all[, 1],
                                                             go2all[, 2])), ]
                     
                     ## Taken from GOstat (Bioconductor)
                     getDataEnv <- function(name, lib) {
                       get(paste(lib, name, sep=""))
                     }

                     ## select the ontologies
                     ONTOLOGIES    <- c("MF","BP","CC")
                     
                     annotations <- list()
                     
                     for (i in ONTOLOGIES)
                       {
                         matchontogo <- match(go2alltable[, 1],
                                              ls(env = getDataEnv(
                                                   paste(i,"CHILDREN", sep =""),
                                                   "GO")
                                                 ))
                         ## save the terms in the annoset (we dont need the evidence codes anymore)
                         annotations[[i]] <- go2alltable[!is.na(matchontogo), 1:2]
                         ## check if we actually have any GO terms left in this ontology
                         if (nrow(annotations[[i]]) == 0)
                           warning(paste("Ontology",i,"has no GO terms left."))
                       }

                     
                     object@annoset <- annotations
                                        
                     object
                   },
                   type = "Lookup"
                   ),
         contains = "clusterAnnotation"
         )
