##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-SIGNIF-BASE
##
##################################################################################

selectStats <- function(X, threshold)
{
  if (is.list(X))
    {
      a <- lapply(X, selectStats, threshold)
      return(a)
    }
  else
    {
      a <- X[ X < threshold ]
      if (length(a) == 0) a <- NA
      return(a)
    }
}

##################################################################################
##
## CLASS CLUSTER-SIGNIF-BASE
##
##################################################################################

setClass("clusterSignifBase",
         representation(
                        threshold = "numeric"
                        ),
         prototype(threshold = 0.05,
                   config = list(
                     threshold =
                     function (object)
                     {
                       selectDouble(paste("Please select the maximal p-value for",
                                          "\nthe selection of GO terms"), 0, 1)
                     }
                     ),
                   setup = list(
                     threshold =
                     function (X, object)
                     {
                       if (as.double(X) == 0)
                         stop(paste("The \"threshold\" value is missing!",
                                    "\nPlease specify a threshold for your",
                                    "\nsignificance analysis!"))
                     }
                     ),
                   execute =
                   function (object, parent)
                   {
                     ## FIXME: Should the parent concept really work like this?
                     ## Wouldn't it be better to 
                     object@stat <- execute(object@stat, parent)
                     
                     object@statset <- object@stat@statset
                     
                     object@selection <- selectStats(object@statset, object@threshold)

                     object
                   }
                   ),
         contains = "clusterSignif"
         )



setMethod("print", "clusterSignifBase", function(x, ...)
          {
            if (length(x@selection)!=0)
              {
                report <- c("The clustered data has been analyzed.",
                            paste("A total of", length(unlist(x@selection)), "annotation terms have been selected")
                            )
              }
            else
              {
                report <- "The object holds no result yet."
              }
            printData("Significance",
                      "Basic Significance Analysis",
                      report
                      )
            print(x@stat)
          }
          )
