##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-SIGNIF-BONFERRONI
##
##################################################################################

selectStatsBonferroni <- function(X, threshold, tests)
{
  if (is.list(X))
    {
      a <- lapply(X, selectStatsBonferroni, threshold, tests)
      return(a)
    }
  else
    {
      a <- X[ X < ( threshold / tests ) ]
      if (length(a) == 0) a <- NA
      return(a)
    }
}

##################################################################################
##
## CLASS CLUSTER-SIGNIF-BONFERRONI
##
##################################################################################

setClass("clusterSignifBonferroni",
         representation(
                        threshold = "numeric"
                        ),
         prototype(threshold = 0.05,
                   config = list(
                     threshold =
                     function (object)
                     {
                       selectDouble(paste("Please select the maximal p-value",
                                          "\nfor the selection of GO terms"), 0, 1)
                     }
                     ),
                   setup = list(
                     threshold =
                     function (X, object)
                     {
                       if (as.double(X) == 0)
                         stop(paste("The \"threshold\" value is missing!",
                                    "\nPlease specify a threshold for your",
                                    "\nsignificance analysis!"))
                       
                     }
                     ),
                   execute =
                   function (object, parent)
                   {
                     object@stat <- execute(object@stat, parent)
                     
                     object@statset <- object@stat@statset

                     object@selection <- selectStatsBonferroni(object@statset, object@threshold, length(unlist(object@statset)))

                     object
                   }
                   ),
         contains = "clusterSignif"
         )

setMethod("print", "clusterSignifBonferroni", function(x, ...)
          {
            if (length(x@selection)!=0)
              {
                report <- c("The clustered data has been analyzed.",
                            paste("A total of", length(unlist(x@selection)), "annotation terms have been selected")
                            )
              }
            else
              {
                report <- "The object holds no result yet."
              }
            printData("Significance",
                      "Bonferroni correction",
                      report
                      )
            print(x@stat)
          }
          )
