##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-STATISTIC-HYPER
##
##################################################################################

groupCount <- function(X)
{
  if (is.list(X))
    {
      a <- sum(unlist(lapply(X, groupCount)))
      return(a)
    }
  else 1
}

evalClusterHyper <- function(X, uniqueid, Annoset)
{
  if (is.list(X))
    {
      a <- lapply(X, evalClusterHyper, uniqueid, Annoset)
      return(a)
    }
  else
    {
      a <- list()
      
      for (i in 1:length(Annoset))
        {
          a[[i]] <- evalAnnosetHyper(X, uniqueid, Annoset[[i]])
        }
      return(a)
    }
}

evalAnnosetHyper <- function(Selection, uniqueid, Annoset)
  {
    ## Convert element index to the element id so that
    ## duplicated entries can be removed here
    Selection <- uniqueid[Selection]
    ## Double and missing values are being removed here
    Selection <- unique(Selection[!is.na(Selection)])
    if (length(Selection) < 2) return(NA)

    ## Get the position of element-annotation links in the
    ## annoset matrix
    SelectedPerAnnotationRaw <- match(Annoset[,2], Selection)

    ## Get the annotations and clean them up
    SelectedAnnotations <- unique(Annoset[!is.na(SelectedPerAnnotationRaw), 1])
    SelectedAnnotations <- SelectedAnnotations[!is.na(SelectedAnnotations)]
    if (length(SelectedAnnotations) < 2) return(NA)

    ## How many elements are present per annotation (GOstats: goCounts)
    ElementsPerAnnotationRaw <- match(Annoset[,1], SelectedAnnotations)
    ElementsPerAnnotation <-
      table(Annoset[!is.na(ElementsPerAnnotationRaw), 1])

    ## How many elements were selected per annotation (GOstats: useCts)
    SelectedElementsPerAnnotation <-
      table(Annoset[!is.na(SelectedPerAnnotationRaw),1])

    ## How many elements are present in total? (GOstats: nLL)
    PresentElements <- Annoset[,2]
    PresentElements <- unique(PresentElements[!is.na(PresentElements)])
    
    ## How many elements are present in the selection? (GOstats: nInt)
    PresentSelection <- Selection[Selection %in% PresentElements]

    ## Return the pvalues and the counts
    return(phyper(SelectedElementsPerAnnotation - 1,
                  length(PresentSelection),
                  length(PresentElements) - length(PresentSelection),
                  ElementsPerAnnotation,
                  lower.tail=FALSE)
           )
    ## FIXME: It might be nice to return more information but it
    ## does not fit the framework like this
#     return(list(pvalues =
#                 phyper(SelectedElementsPerAnnotation - 1,
#                   length(PresentSelection),
#                   length(PresentElements) - length(PresentSelection),
#                   ElementsPerAnnotation,
#                   lower.tail=FALSE),
#                 selectedPerAnnotation = SelectedElementsPerAnnotation,
#                 elementsPerAnnotation = ElementsPerAnnotation,
#                 selectedTotal = length(PresentSelection),
#                 elementsTotal = length(PresentElements)
#            ))
  }

##################################################################################
##
## CLASS CLUSTER-STATISTIC-HYPER
##
##################################################################################

setClass("clusterStatisticHyper",
         representation(
                        ),
         prototype(config = list(),
                   setup  = list(),
                   execute =
                   function(object, parent)
                   {
                     if (length(object@statset)>0)
                       {
                         warning("The clustered genes have already been analyzed! Ignoring \"execute\" call!")
                         return
                       }
                     
                     if (is.null(parent))
                       stop("The object needs to have a defined parent before it can be used!")

                     totalGroups <- groupCount(parent@algo@clusterset)
                     
                     cat("\nGoing to analyze", totalGroups, " groups.\nThis might take a while...\n")
                     
                     result <- evalClusterHyper(parent@algo@clusterset,
                                                parent@data@anno@uniqueid,
                                                parent@data@anno@annoset
                                                )
                     
                     object@statset <- result
                                                            
                     object
                     
                   }
                   ),
         contains = "clusterStatistic"
         )

setMethod("print", "clusterStatisticHyper", function(x, ...)
          {
            printData("Statistic",
                      "Hypergeometric distribution",
                      c(ifelse(length(x@statset)!=0, paste("A total of", groupCount(x@statset), "clusters (this might include randomized datasets) have been analyzed."), "The object holds no result yet.")))
          }
          )
