##################################################################################
##
## FUNCTIONS FOR CLASS CLUSTER-VISUAL-HEATMAP
##
##################################################################################

prepareHeatmap <- function(X, Clusters, Annoset, Dataset, ID)
{
  if (length(X)==0) return(NA)
  if (is.list(X[[1]]))
    {
      a <- list()
      for (i in 1:length(X))
        {
          a[[i]] <- prepareHeatmap(X[[i]], Clusters[[i]], Annoset, Dataset, ID)
        }
      return(a)
    }
  else
    {
      a <- list()
      a[["group"]] <- Clusters
      a[["annot"]] <- list()
      for (i in 1:length(X))
        {
          if (all(is.na(X[[i]])))
            {
              a[["annot"]][[i]] <- NA
            }
          else
            {    
              a[["annot"]][[i]] <- list()
              for (j in 1:length(X[[i]]))
                {
                  term <- names(X[[i]])[j]
                  pval <- X[[i]][j]
                  selectedElements <- ID[Clusters]
                  possibleElements <- Annoset[[i]][Annoset[[i]][,1] == term, 2]
                  matchingElements <- !is.na(match(selectedElements,
                                                   possibleElements))
                  data <- Dataset[Clusters[matchingElements],]
                  a[["annot"]][[i]][[term]] <- list(pval     = pval,
                                                    features = Clusters[matchingElements],
                                                    data     = data)
                }
            }
        }
      return(a)
    }
}

selectTerms <- function(goCluster, terms)
  {
    if (class(goCluster@visu)!="clusterVisualHeatmap")
      stop("Sorry this method is meant to be used with a goCluster object that provides a Heatmap visualization method.")

    result <- list()

    grabTerms <- function(tree, terms, result)
      {
        if (length(tree)==0) return(NA)
        if (is.null(tree[["group"]]))
          {
            for (i in 1:length(tree))
                result <- grabTerms(tree[[i]], terms, result)
          }
        else
          {
            for (i in 1:length(tree[["annot"]]))
              {
                hits <- match(names(tree[["annot"]][[i]]), terms)
                if (length(hits[!is.na(hits)]) > 0)
                  result <- c(result, tree[["annot"]][[i]][!is.na(hits)])
              }
          }
        return(result)
      }
    grabTerms(goCluster@visu@prepared, terms, result)
  }


collectTerms <- function(tree)
  {
    if (length(tree)==0) return(NA)
    if (is.null(tree[["group"]]))
      {
        result <- lapply(tree, collectTerms)
      }
    else
      {
        result <- lapply(tree[["annot"]],names)
      }
    return(result)
  }

##################################################################################
##
## CLASS CLUSTER-VISUAL-HEATMAP
##
##################################################################################

setClass("clusterVisualHeatmap",
         representation(
                        prepared = "list"
                        ),
         contains = "clusterVisual",
         prototype = list(
           execute =
           function (object, parent)
           {
             object@prepared <- prepareHeatmap(parent@sign@selection,
                                               parent@algo@clusterset,
                                               parent@data@anno@annoset,
                                               exprs(parent@data@dataset),
                                               parent@data@anno@uniqueid)
             
             object
           }
           )
         )

setMethod("print", "clusterVisualHeatmap", function(x, ...)
          {
            if (length(x@prepared)!=0)
              {
                terms <- table(unlist(collectTerms(x@prepared)))
                report <- c("The clustered data has been prepared for visualization.",
                            paste("A total of", length(terms), "annotation terms can be visualized.","\n"),
                            "These are the annotation terms that were found to be significantly enriched.",
                            "(The number indicates how often each term has been identified):\n"
                            )
                for (i in 1:length(terms))
                  report <- c(report, paste(names(terms)[i],"---",terms[i],"time(s)"))
              }
            else
              {
                report <- "The object holds no result yet."
              }
            printData("Visualization",
                      "Heatmap",
                      report
                      )
          }
          )

setMethod("display", "clusterVisualHeatmap", function(object, parent, selection, ...)
          {
            if (missing(selection))
              stop("You need to select an annotation term that should be displayed (specify selection=\"xyz\" in the function call).\nPrint this object in order to receive a list of available terms.\n")
            
            result <- selectTerms(parent, selection)
            
            genecolors <- getGeneColors()

            if (is.list(result) && length(result) > 0)
              {
                ## Setup data
                x <- result[[1]][["data"]]
                y <- result[[1]][["features"]]
                if (length(result) > 1)
                  {
                    for (i in 2:(length(result)))
                      {
                        if (any(is.na(match(result[[i]][["features"]],y))))
                          {
                            z <- is.na(match(result[[i]][["features"]],y))
                            y <- c(y, result[[i]][["features"]][z])
                            w <- c(rownames(x), rownames(result[[i]][["data"]])[z])
                            x <- rbind(x, result[[i]][["data"]][z,])
                            rownames(x) <- w
                          }
                      }
                  }
              }
            else
              {
                stop("The term you selected has not been found among the list of available terms. \nPrint this object in order to receive a list of available terms.\n")
              }

            if (dim(x)[2] < 40)
              {
                ## Image format
                par(mar = c(5, 2, 4, 7) + 0.1)
              }
            
            ## Heatmap
            image(1:ncol(x),
                  1:nrow(x),
                  t(x),
                  axes = FALSE,
                  xlim = c(0.5,ncol(x) + 0.5),
                  ylim = c(0.5, nrow(x) + 0.5),
                  col = rgb(genecolors[1,],
                    genecolors[2,],
                    genecolors[3,],
                    maxColorValue=255),
                  main = selection,
                  xlab = "",
                  ylab = "")

            if (dim(x)[2] < 40)
              {
                ## Axis and labels
                axis(1, at=1:dim(x)[2], labels = colnames(x), las = 2)
                axis(4,
                     at = 1:dim(x)[1],
                     labels = rownames(x),
                     las = 2,
                     tick=FALSE,
                     lwd = 0,
                     cex=0.7)
              }
          }
          )
