\name{checkProtection}

\alias{checkProtection}

\title{A function to protect intermediate results from being overwritten}

\description{
  This function can be called by a method that will overwrite object data.
  \code{checkProtection} will retrieve the list in the \code{reset}-slot
  of the given object. The names of elements in this list will be
  considered as slot names and each list element will be compared
  against the value in the corresponding slot. If the length of any such
  pairs differs an error message will be issued.
}

\usage{
checkProtection(object, method)
}

\arguments{
  \item{object}{The object to check}
  \item{method}{A string that names the method trying to overwrite
    data. It will be included in the error message.}
}

\value{
  An error message in case the calling method would overwrite already
  calculated values.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterModule-class}}.
}

\examples{

data(benomylsetupsmall)
a <- new("goCluster")

## No error since the object has not been calculated yet
checkProtection(a@algo,"test")

execute(a) <- benomylsetupsmall

## This results in an error since the object contains calculated data
error <- try(checkProtection(a@algo,"test"), silent = TRUE)
error

## No error since no visualization method has been chosen
checkProtection(a@visu,"test")

}

\keyword{ utilities }
