\name{clusterAlgorithmClara-class}

\docType{class}

\alias{clusterAlgorithmClara-class}
\alias{config,clusterAlgorithmClara-method}
\alias{execute,clusterAlgorithmClara-method}
\alias{reset,clusterAlgorithmClara-method}
\alias{setup<-,clusterAlgorithmClara-method}
\alias{setup,clusterAlgorithmClara-method}
\alias{print,clusterAlgorithmClara-method}

\title{Class "clusterAlgorithmClara", provides partitioning around
  medoids of large datasets}

\description{This can be used to group a dataset according to
  partitioning around medoids. The resulting gene groups can 
  subsequently be analysed for significant enrichment of specific
  annotations.
} 

\section{Slots}{
  \describe{
    \item{\code{clusters}:}{Object of class \code{"numeric"}, determines
      the number of clusters the partitioning around medoids will
      identify.}
    \item{\code{repeats}:}{Object of class \code{"numeric"}, specifies
      how often the clustering is repeated in case clara is not run with
      a fixed initialization.}
    \item{\code{fixed}:}{Object of class \code{"logical"}, if true, a
      fixed seed will be used for the partitioning around medoids. }
    \item{\code{distance}:}{Object of class \code{"character"},
      specifies the distance matrix that will be used.}
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterAlgorithm-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAlgorithm"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAlgorithm"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAlgorithmClara")}:
      interactive setup of the class. You will be asked to specify the
      number of clusters clara clustering should result in and whether a
      fixed seed should be used. If not the class offers to repeat the
      clustering. In addition the distance matrix needs to be defined.}
    \item{setup}{\code{signature(object = "clusterAlgorithmClara")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAlgorithmClara")}:
      non-interactive setup of the class. The options are specified
      using a list. }
    \item{execute}{\code{signature(object = "clusterAlgorithmClara")}: run the
      clustering. }
    \item{reset}{\code{signature(object = "clusterAlgorithmClara")}: remove all
      cluster data so that the \code{execute} function can be run again.}
    \item{print}{\code{signature(object = "clusterAlgorithmClara")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{clusterclara}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterclara}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAlgorithm-class}},
  \code{\link{clusterAlgorithmKmeans-class}},
  \code{\link{clusterAlgorithmPam-class}},
  \code{\link{clusterAlgorithmHclust-class}},
.} 

\examples{
## Predefined setup for goCluster
## (This configuration selects the
## clara clustering)
data(benomylsetup)

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## Retrieve annotation
test@data <- execute(test@data, test)

## Cluster the dataset
test@algo <- execute(test@algo, test)
}

\keyword{cluster}

