\name{clusterAlgorithmHclust-class}

\docType{class}

\alias{HCLUSTMETHOD}
\alias{HCLUSTDISTANCE}
\alias{clusterAlgorithmHclust-class}
\alias{config,clusterAlgorithmHclust-method}
\alias{execute,clusterAlgorithmHclust-method}
\alias{reset,clusterAlgorithmHclust-method}
\alias{setup<-,clusterAlgorithmHclust-method}
\alias{setup,clusterAlgorithmHclust-method}
\alias{print,clusterAlgorithmHclust-method}

\title{Class "clusterAlgorithmHclust", provides hierarchical clustering
  for goCluster.}

\description{This can be used to group an expression dataset according to
  hierarchical clustering. The resulting gene groups can subsequently be
  analysed for significant enrichment of specific annotations.} 

\section{Slots}{
  \describe{
    \item{\code{tree}:}{Object of class \code{"hclust"}, holds another
      copy of the clustering result (the direct result from the call to
      hclust). }
    \item{\code{method}:}{Object of class \code{"character"}, defines
      the agglomeration method that is going to be used for the
      hierarchical clustering.}
    \item{\code{distance}:}{Object of class \code{"character"},
      specifies the distance matrix that will be used.}
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterAlgorithm-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAlgorithm"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAlgorithm"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAlgorithmHclust")}:
      interactive setup of the class. You will be asked to specify the
      distance matrix as well as the agglomeration method.}
    \item{setup}{\code{signature(object = "clusterAlgorithmHclust")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAlgorithmHclust")}:
      non-interactive setup of the class. The options are specified
      using a list.}
    \item{execute}{\code{signature(object = "clusterAlgorithmHclust")}: run the
      clustering.}
    \item{reset}{\code{signature(object = "clusterAlgorithmHclust")}: remove all
      cluster data so that the \code{execute} function can be run
      again.}
    \item{print}{\code{signature(object = "clusterAlgorithmHclust")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{clusterhclust}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterhclust}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAlgorithm-class}},
  \code{\link{clusterAlgorithmKmeans-class}},
  \code{\link{clusterAlgorithmClara-class}},
  \code{\link{clusterAlgorithmPam-class}}
} 

\examples{
## Predefined setup for goCluster
data(benomylsetup)

## Change the setup to
## hierarchical clustering
benomylsetup$data$dataset  <- benomylsetup$data$dataset[1:200,]
benomylsetup$data$uniqueid <- benomylsetup$data$uniqueid[1:200]
benomylsetup$classalgo <- "clusterAlgorithmHclust"
benomylsetup$algo$method   <- "complete"
benomylsetup$algo$distance <- "euclidean"

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## Retrieve annotation
test@data <- execute(test@data, test)

## Cluster the dataset
test@algo <- execute(test@algo, test)

}

\keyword{classes}

