\name{clusterAlgorithmKmeans-class}
\docType{class}

\alias{clusterAlgorithmKmeans-class}
\alias{config,clusterAlgorithmKmeans-method}
\alias{execute,clusterAlgorithmKmeans-method}
\alias{reset,clusterAlgorithmKmeans-method}
\alias{setup<-,clusterAlgorithmKmeans-method}
\alias{setup,clusterAlgorithmKmeans-method}
\alias{print,clusterAlgorithmKmeans-method}

\title{Class "clusterAlgorithmKmeans", provides kmeans clustering for goCluster.}

\description{This can be used to group a dataset according to
  kmeans. The resulting gene groups can subsequently be
  analysed for significant enrichment of specific annotations.} 

\section{Slots}{
  \describe{
    \item{\code{repeats}:}{Object of class \code{"numeric"}, specifies
      how often the clustering should be repeated to account for the
      statistical variability of the clustering.}
    \item{\code{clusters}:}{Object of class \code{"numeric"}, determines
      the number of clusters the kmeans clustering will identify.}
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterAlgorithm-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAlgorithm"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAlgorithm"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAlgorithmKmeans")}:
      interactive setup of the class. You will be asked to specify the
      number of clusters the kmeans clustering should result in and how
      often the clustering should be repeated.}
    \item{setup}{\code{signature(object = "clusterAlgorithmKmeans")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAlgorithmKmeans")}:
      non-interactive setup of the class. The options are specified
      using a list.}
    \item{execute}{\code{signature(object = "clusterAlgorithmKmeans")}: run the
      clustering. }
    \item{reset}{\code{signature(object = "clusterAlgorithmKmeans")}: remove all
      cluster data so that the \code{execute} function can be run
      again.}
    \item{print}{\code{signature(object = "clusterAlgorithmKmeans")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{clusterkmeans}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterkmeans}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAlgorithm-class}},
  \code{\link{clusterAlgorithmKmeans-class}},
  \code{\link{clusterAlgorithmClara-class}},
  \code{\link{clusterAlgorithmPam-class}}
} 


\examples{
## Predefined setup for goCluster
data(benomylsetup)

## Change the setup to
## hierarchical clustering
benomylsetup$classalgo <- "clusterAlgorithmKmeans"
benomylsetup$algo$repeats   <- 10

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## Retrieve annotation
test@data <- execute(test@data, test)

## Cluster the dataset
test@algo <- execute(test@algo, test)

}

\keyword{cluster}

