\name{clusterAlgorithmPam-class}

\docType{class}

\alias{clusterAlgorithmPam-class}
\alias{config,clusterAlgorithmPam-method}
\alias{execute,clusterAlgorithmPam-method}
\alias{reset,clusterAlgorithmPam-method}
\alias{setup<-,clusterAlgorithmPam-method}
\alias{setup,clusterAlgorithmPam-method}
\alias{print,clusterAlgorithmPam-method}

\title{Class "clusterAlgorithmPam", provides partitioning around medoids
  for goCluster.}

\description{This can be used to group a dataset according to
  partitioning around medoids. The resulting gene groups can subsequently be
  analysed for significant enrichment of specific annotations.} 

\section{Slots}{
  \describe{
    \item{\code{clusters}:}{Object of class \code{"numeric"}, determines
      the number of clusters partitioning around medoids will
      identify.}
    \item{\code{distance}:}{Object of class \code{"character"},
      specifies the distance matrix that will be used.}
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterAlgorithm-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAlgorithm"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAlgorithm"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAlgorithmPam")}:
      interactive setup of the class. You will be asked to specify the
      number of clusters PAM clustering should result in. In addition
      the distance matrix needs to be defined.}
    \item{setup}{\code{signature(object = "clusterAlgorithmPam")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAlgorithmPam")}:
      non-interactive setup of the class. The options are specified
      using a list. }
    \item{execute}{\code{signature(object = "clusterAlgorithmPam")}: run the
      clustering. }
    \item{reset}{\code{signature(object = "clusterAlgorithmPam")}: remove all
      cluster data so that the \code{execute} function can be run again.}
    \item{print}{\code{signature(object = "clusterAlgorithmPam")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{clusterpam}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterpam}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAlgorithm-class}},
  \code{\link{clusterAlgorithmKmeans-class}},
  \code{\link{clusterAlgorithmClara-class}},
  \code{\link{clusterAlgorithmHclust-class}},
.} 


\examples{
## Predefined setup for goCluster
## (This configurations selects the
## clara clustering)
data(benomylsetup)

## Change the setup to
## pam clustering
benomylsetup$data$dataset  <- benomylsetup$data$dataset[1:200,]
benomylsetup$data$uniqueid <- benomylsetup$data$uniqueid[1:200]
benomylsetup$classalgo <- "clusterAlgorithmPam"

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## Retrieve annotation
test@data <- execute(test@data, test)

## Cluster the dataset
test@algo <- execute(test@algo, test)
}

\keyword{cluster}

