\name{clusterAnnotationChromosome-abp-class}

\docType{class}

\alias{clusterAnnotationChromosome-abp-class}
\alias{config,clusterAnnotationChromosome-abp-method}
\alias{execute,clusterAnnotationChromosome-abp-method}
\alias{reset,clusterAnnotationChromosome-abp-method}
\alias{setup<-,clusterAnnotationChromosome-abp-method}
\alias{setup,clusterAnnotationChromosome-abp-method}
\alias{print,clusterAnnotationChromosome-abp-method}

\title{Class "clusterAnnotationChromosome-abp", prepares the chromosome
  annotation for subsequent statistical analysis.}

\description{This class can be used to retrieve the chromosome
  information for subsequent use in a \code{goCluster}-analysis. } 

\section{Slots}{
  \describe{
    \item{\code{meta}:}{Object of class \code{"character"},
      specifies the AnnBuilder meta package that the class will use for
      the lookup of chromosome information.}
    \item{\code{trueid}:}{Object of class \code{"character"},
      describes which id has actually been used for the building of the
      annotation package (this is important for some of the AnnBuilder
      packages that use LocusLink as central ID.}
    \item{\code{uniqueid}:}{Object of class \code{"character"},
      this is either a copy of the unique id of the parent data object
      (in case this is also the true ID) or a transformed vector
      according to the setting of the true ID.}
    \item{\code{chromosomes}:}{Object of class \code{"character"},
      this can be used to limit the analysis to specific
      chromosomes.}
  }

  Additional slots are described in the documentation of the
  \code{\link{clusterAnnotation-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAnnotation"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAnnotation"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAnnotationChromosome")}:
      interactive setup of the class. You will be asked to specify the
      annotation package name and the chromosomes that
      you wish to include in your analysis. In addition the true linking
      ID can be specified.}
    \item{setup}{\code{signature(object = "clusterAnnotationChromosome")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAnnotationChromosome")}:
      non-interactive setup of the class. The options are specified
      using a list. }
    \item{execute}{\code{signature(object = "clusterAnnotationChromosome")}:
      build the chromosome annotation information.}
    \item{reset}{\code{signature(object = "clusterAnnotationChromosome")}:
      remove all annotation data that has been retrieved so that the
      \code{execute} function can be run again.}
    \item{print}{\code{signature(object = "clusterAnnotationChromosome")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{prepareCHRannotation}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{prepareCHRannotation}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAnnotation-class}},
  \code{\link{clusterData-class}}
} 


\examples{
## Predefined setup for goCluster
data(benomylsetup)

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## We only use the dataset from this object
data <- test@data

## The predefined configuration is set to retrieve the
## gene ontology information. We need to exchange this
## with chromosome annotation
anno <- new("clusterAnnotationChromosome-abp")
setup(anno) <- list(meta = "YEAST",
                    chromosomes = as.character(seq(1:16)),
                    trueid = "")
data@anno <- anno

## Get the annotation to the dataset
testAnnotation <- execute(data@anno, test)

}

\keyword{classes}

