\name{clusterAnnotationGO-abp-class}

\docType{class}

\alias{EVIDENCECODES}
\alias{ONTOLOGIES}
\alias{clusterAnnotationGO-abp-class}
\alias{config,clusterAnnotationGO-abp-method}
\alias{execute,clusterAnnotationGO-abp-method}
\alias{reset,clusterAnnotationGO-abp-method}
\alias{setup<-,clusterAnnotationGO-abp-method}
\alias{setup,clusterAnnotationGO-abp-method}
\alias{print,clusterAnnotationGO-abp-method}

\title{Class "clusterAnnotationGO-abp", prepares the GO annotation for
  subsequent statistical analysis.}
\description{This class can be used to reorganize the GO annotation from
  an AnnBuilder meta package to make it suitable for the statistical
  analysis.} 

\section{Slots}{
  \describe{
    \item{\code{meta}:}{Object of class \code{"character"},
      specifies the \code{AnnBuilder} meta package which the class will
      use for the lookup of the initial GO IDs.}
    \item{\code{trueid}:}{Object of class \code{"character"},
      describes which unique ID has been used for building the
      annotation data package. This option is important in case your
      dataset is annotated with a different unique ID. In this case
      \code{goCluster} will have to convert the IDs of the dataset into the
      corresponding annotation IDs before removing duplicate entries.) }
    \item{\code{uniqueid}:}{Object of class \code{"character"},
      this is either a copy of the unique id of the parent data object
      (in case this is also the true ID) or a transformed vector
      according to the setting of the true ID. }
    \item{\code{ontologies}:}{Object of class \code{"character"},
      specifies one or several of the three GO ontologies that should be
      analyzed.}
    \item{\code{evidence}:}{Object of class \code{"character"},
      sets the evidence codes that are considered to be acceptable in
      the analysis.}
  }

  Additional slots are described in the documentation of the
  \code{\link{clusterAnnotation-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterAnnotation"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterAnnotation"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterAnnotationGO")}:
      interactive setup of the class. You will be asked to specify the
      annotation package name and the sections of the gene ontology that
      you wish to include in your analysis. In addition unacceptable
      evidence codes can be excluded and the true linking ID can be
      specified.}
    \item{setup}{\code{signature(object = "clusterAnnotationGO")}:
      returns the configuration of the object as a list. This list can
      again be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterAnnotationGO")}:
      non-interactive setup of the class. The options are specified
      using a list. }
    \item{execute}{\code{signature(object = "clusterAnnotationGO")}:
      build the GO annotation information.}
    \item{reset}{\code{signature(object = "clusterAnnotationGO")}:
      remove all annotation data that has been retrieved so that the
      \code{execute} function can be run again.}
    \item{print}{\code{signature(object = "clusterAnnotationGO")}:
      This function prints some basic information about the content of
      this object.}
  }
}

\details{
  The class provides a wrapper around the \code{prepareGOannotation}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{prepareGOannotation}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterAnnotation-class}},
  \code{\link{clusterData-class}}
} 

\examples{

## Predefined setup for goCluster
data(benomylsetup)

## Setup a new goCluster object
test <- new("goCluster")
setup(test) <- benomylsetup

## We only use the dataset from this object
data <- test@data

## Get the annotation to the dataset
testAnnotation <- execute(data@anno, test)

}

\keyword{classes}

