\name{clusterData-class}

\docType{class}

\alias{clusterData-class}
\alias{config,clusterData-method}
\alias{execute,clusterData-method}
\alias{reset,clusterData-method}
\alias{setup<-,clusterData-method}
\alias{setup,clusterData-method}
\alias{print,clusterData-method}

\title{Class "clusterData", a class for holding datasets that are going
  to be analysed with goCluster.}

\description{This class provides a container for microarray data.} 

\section{Slots}{
  \describe{
    \item{\code{name}:}{Object of class \code{"character"}, a
      name for the dataset.}
    \item{\code{dataset}:}{Object of class \code{"exprSet"}, the dataset
      for the analysis.}
    \item{\code{uniqueid}:}{Object of class \code{"character"}, the
      unique id for each gene (row) in the dataset.}
    \item{\code{anno}:}{Object of class \code{"clusterAnnotation"}, the
      annotation object that holds the annotation to this dataset.}
  }

  Additional slots are described in the documentation of the
  \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterModule"}, directly.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterData")}: interactive
      setup of the class. }
    \item{setup}{\code{signature(object = "clusterData")}: returns the
      configuration (including the dataset) of the object as a
      list. This list can be used for the non-interactive setup of the
      class.}
    \item{setup<-}{\code{signature(object = "clusterData")}:
      non-interactive setup of the class. The options are specified
      using a list. }
    \item{execute}{\code{signature(object = "clusterData")}: passes the
      \code{execute}-call to the annotation object. }
    \item{execute<-}{\code{signature(object = "clusterData")}: passes the
      \code{execute<-}-call to the annotation object. }
    \item{reset}{\code{signature(object = "clusterData")}: This only
      conveys the reset signal to the clusterAnnotation
      object. The dataset of the clusterData object will not be removed
      by this reset method. A new \code{goCluster}-object should be created for
      each new dataset. }
    \item{print}{\code{signature(object = "clusterData")}: calls the
      print function of the exprSet-object stored in the dataset slot. }
  }
}

\details{

This class provides a wrapper for \code{exprSet} objects from bioconductor. It
provides a link to the annotation data in goCluster. A vector of
unique ids that connects each element (row) in the dataset with its
corresponding annotation terms has to be provided.
  
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{goCluster-class}},
  \code{\link{clusterAnnotation-class}},
  \code{\link{setup}},
  \code{\link{setup<-}},
  \code{\link{execute}},
  \code{\link{reset}}.
}

\keyword{classes}

