\name{clusterModule-class}

\docType{class}

\alias{clusterModule-class}
\alias{config,clusterModule-method}
\alias{execute,clusterModule-method}
\alias{execute<-,clusterModule-method}
\alias{reset,clusterModule-method}
\alias{setup,clusterModule-method}
\alias{setup<-,clusterModule-method}

\title{Class "clusterModule" represents the base class for all goCluster
  objects}

\description{
  This is the central class in \code{goCluster} and is being used to abstract
  the configuration and execution of \code{goCluster}-objects.
}

\section{Slots}{
  \describe{
    \item{\code{config}:}{Object of class \code{"list"}. A list of
      functions that will be called by the \code{config} method of this
      object. The name of each list entry specifies the slot that will
      be set by the function.}
    \item{\code{setup}:}{Object of class \code{"list"}. A list of
      functions that will be used by the \code{setup} and \code{setup<-}
      methods of this object. The \code{setup} method will only read the
      slot names and return the corresponding slots of the object as a
      list. Such a list can be used with the \code{setup<-} call in order
      to assign the configuration to a new \code{goCluster} object. The
      \code{setup<-} will use the functions stored in this list to verify
      that each setting is in the limits defined for this slot.}
    \item{\code{execute}:}{Object of class \code{"function"}. This is
      the main function of the object that will be called from the
      \code{execute} function of this object.}
    \item{\code{reset}:}{Object of class \code{"list"}. A list that
      names the slots which hold protected results and holds the empty
      value for each of these slots. In case any of these slots contains
      data, the \code{execute} function will fail on this object. The
      \code{reset} method will fill each of the slots with the
      corresponding empty value.}
    \item{\code{children}:}{Object of class \code{"character"}. A vector
      of names that specifies the children of this object. This vector
      enables the different methods of a \code{clusterModule} to
      automatically recurse through a  "tree" of objects.}
  }
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterModule")}: This will
      call the interactive setup for the object and iterate through the
      elements in the \code{config} slot. }
    \item{execute}{\code{signature(object = "clusterModule")}: This will
      execute the object and all of its children. }
    \item{execute<-}{\code{signature(object = "clusterModule")}: This
      will first call the \code{setup<-} method to set the configuration.
      Subsequently \code{execute} will be called. This method simplifies
      configuration and execution of a \code{goCluster} object to a
      single call.}
    \item{reset}{\code{signature(object = "clusterModule")}: Resets the
      object by setting each of the slots named in the \code{reset} slot
      of this object to the corresponding element in that list.}
    \item{setup}{\code{signature(object = "clusterModule")}: Return the
      configuration of the object as a list. }
    \item{setup<-}{\code{signature(object = "clusterModule")}: Assigns
      the given list as a configuration to the object. The method will
      check each setting against the functions specified in the
      \code{setup} slot of this object. }
  }
}

\details{
  \code{goCluster} has been created as an object oriented package to
  build a modular structure that allows to easily modify and extend the
  functionality of the package.
  The \code{clusterModule}-class abstracts the configuration and
  execution of the different modules.

  The \code{config}, \code{setup}, and \code{setup<-} methods can be
  used for the module configuration while the \code{execute} and
  \code{reset} methods are concerned with the execution of the objects. 
  
  For further information on extending \code{goCluster} and the internal
  structures you are referred to the "Developers Manual" of goCluster
  which is included in the package as a vignette.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{goCluster-class}},
}

\keyword{classes}
