\name{clusterSignif-class}

\docType{class}

\alias{clusterSignif-class}
\alias{config,clusterSignif-method}
\alias{execute,clusterSignif-method}
\alias{reset,clusterSignif-method}
\alias{setup<-,clusterSignif-method}
\alias{setup,clusterSignif-method}
\alias{print,clusterSignif-method}

\title{Class "clusterSignif"}

\description{An abstract class that provides a framework for the
   significance analysis methods provided by \code{goCluster}.} 

\section{Slots}{
  \describe{
    \item{\code{statset}:}{Object of class \code{"list"}, this slot
      contains the statistical values that the class will use in order
      to decide which annotation terms are interesting or not. This can
      be a simple copy of the underlying \code{clusterStatistic} object
      but it can as well hold corrected value depending on the function
      of this class.}
    \item{\code{selection}:}{Object of class \code{"list"}, this is the
      list of elements that were selected by the algorithm as being
      interesting.}
    \item{\code{stat}:}{Object of class \code{"clusterStatistic"}, the
      statistical method that is used to identify interesting
      gene groups.}
  }

  Additional slots are described in the documentation for the
  \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterModule"}, directly.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterModule")}:
      This function does nothing since this is an abstract class.}
    \item{setup}{\code{signature(object = "clusterModule")}:
      This function returns an empty list since this is an abstract
      class.}
    \item{setup<-}{\code{signature(object = "clusterModule")}:
      This function does nothing since this is an abstract class.}
    \item{execute}{\code{signature(object = "clusterModule")}:
      This function does nothing since this is an abstract class.}
    \item{execute<-}{\code{signature(object = "clusterModule")}:
      This function does nothing since this is an abstract class.}
    \item{reset}{\code{signature(object = "clusterModule")}:
      This function resets the \code{clusterset}-slot to an empty list.}
    \item{print}{\code{signature(object = "clusterModule")}:
      This function does nothing since this is an abstract class.}
  }
}

\details{

  This class provides a wrapper for the selection algorithms employed by
  \code{goCluster}. The class provides a slot to hold the class that is being
  used for the statistical analysis and a slot for the selected
  annotation terms. 
  
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterSignifBase-class}},
  \code{\link{clusterSignifBonferroni-class}},
  \code{\link{clusterSignifFDR-class}}
}

\keyword{classes}

