\name{clusterSignifBase-class}

\docType{class}

\alias{clusterSignifBase-class}
\alias{config,clusterSignifBase-method}
\alias{execute,clusterSignifBase-method}
\alias{reset,clusterSignifBase-method}
\alias{setup<-,clusterSignifBase-method}
\alias{setup,clusterSignifBase-method}
\alias{print,clusterSignifBase-method}

\title{Class "clusterSignifBase"}

\description{ This class provides a very simple selection mechanism to
  identify interesting annotation terms. } 

\section{Slots}{
  \describe{
    \item{\code{threshold}:}{Object of class \code{"numeric"}, the
      threshold for selecting interesting annotation terms. This
      threshold is applied to the statistic returned by the
      \code{clusterStatistic}-class and any terms with a p-value
      lower than the threshold will be returned.}
  }

  Additional slots are described in the documentation of the
  \code{\link{clusterSignif-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterSignif"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterSignif"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterSignifBase")}:
      interactive setup of the class. You can set the threshold here.}
    \item{setup}{\code{signature(object = "clusterSignifBase")}:
      returns the configuration of the object as a list. This list can
      be used for the non-interactive setup of this class. }
    \item{setup<-}{\code{signature(object = "clusterSignifBase")}:
      non-interactive setup of the class. You need to provide a list
      that contains the necessary settings for the class. }
    \item{execute}{\code{signature(object = "clusterSignifBase")}:
      selects annotation terms that have a p-value lower than the given
      threshold. }
    \item{reset}{\code{signature(object = "clusterSignifBase")}:
      resets the results of this class so that the selection process can
      be run again. }
    \item{print}{\code{signature(object = "clusterSignifBase")}:
      This function prints some basic information about the content of
      this object. If the object has been executed, it will show the
      number of identified annotation terms. }
  }
}


\details{
  The class provides a wrapper around the \code{selectStats}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{selectStats}},
  \code{\link{goCluster-class}},
  \code{\link{clusterSignif-class}},
  \code{\link{clusterModule-class}}
}

\examples{

## Load a small test dataset
data(benomylsetupsmall)

## Create an emty goCluster object
test <- new("goCluster")

## Modify the configuration to use this significance class
benomylsetupsmall$classsign <- "clusterSignifBase"

## Assign the configuration to the object and directly execute it
execute(test) <- benomylsetupsmall

## This should show you the selected annotations. They should
## all have a value below 0.05.
test@sign@selection

}

\keyword{classes}

