\name{clusterSignifBonferroni-class}

\docType{class}

\alias{clusterSignifBonferroni-class}
\alias{config,clusterSignifBonferroni-method}
\alias{execute,clusterSignifBonferroni-method}
\alias{reset,clusterSignifBonferroni-method}
\alias{setup<-,clusterSignifBonferroni-method}
\alias{setup,clusterSignifBonferroni-method}
\alias{print,clusterSignifBonferroni-method}

\title{Class "clusterSignifBonferroni"}

\description{ This class provides a selection mechanism that uses
  Bonferroni correction before selecting interesting annotation terms. } 

\section{Slots}{
  \describe{
    \item{\code{threshold}:}{Object of class \code{"numeric"}, the
      threshold for selecting interesting annotation terms. This
      threshold is applied to the Bonferroni corrected statistic
      and any terms with a p-value lower than the threshold will be
      returned.}
  }

  Additional slots are described in the documentation of the
  \code{\link{clusterSignif-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterSignif"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterSignif"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterSignifBonferroni")}:
      interactive setup of the class. You can set the threshold here.}
    \item{setup}{\code{signature(object = "clusterSignifBonferroni")}:
      returns the configuration of the object as a list. This list can
      be used for the non-interactive setup of this class. }
    \item{setup<-}{\code{signature(object = "clusterSignifBonferroni")}:
      non-interactive setup of the class. You need to provide a list
      that contains the necessary settings for the class. }
    \item{execute}{\code{signature(object = "clusterSignifBonferroni")}:
      selects annotation terms that have a p-value lower than the given
      threshold. }
    \item{reset}{\code{signature(object = "clusterSignifBonferroni")}:
      resets the results of this class so that the selection process can
      be run again. }
    \item{print}{\code{signature(object = "clusterSignifBonferroni")}:
      This function prints some basic information about the content of
      this object. If the object has been executed, it will show the
      number of identified annotation terms. }
  }
}

\details{
  The class provides a wrapper around the \code{selectStatsBonferroni}
  function. Please read the corresponding documentation for further
  details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{selectStatsBonferroni}},
  \code{\link{goCluster-class}},
  \code{\link{clusterSignif-class}},
  \code{\link{clusterModule-class}}.
}

\examples{

## Load a small test dataset
data(benomylsetupsmall)

## Create an emty goCluster object
test <- new("goCluster")

## Modify the configuration to use this significance class
benomylsetupsmall$classsign <- "clusterSignifBonferroni"

## Assign the configuration to the object and directly execute it
execute(test) <- benomylsetupsmall

## Bonferroni correction will not find any significant annotation
## terms in this very reduced dataset. You can try to use the full
## benomyl dataset.
test@sign@selection

}

\keyword{classes}

