\name{clusterSignifFDR-class}

\docType{class}

\alias{clusterSignifFDR-class}
\alias{config,clusterSignifFDR-method}
\alias{execute,clusterSignifFDR-method}
\alias{reset,clusterSignifFDR-method}
\alias{setup<-,clusterSignifFDR-method}
\alias{setup,clusterSignifFDR-method}
\alias{print,clusterSignifFDR-method}

\title{Class "clusterSignifFDR"}

\description{ This class provides a selection mechanism that uses
  the false dicovery rate (FDR) to identify annotation terms which are
  significantly enriched in selected gene groups. } 

\section{Slots}{
  \describe{
    \item{\code{threshold}:}{Object of class \code{"numeric"}, this
      specifies the fraction of selected annotation elements that
      would also be identified from random data. The class will select
      as many elements as possible until this threshold is reached.}
    \item{\code{randomstat}:}{Object of class \code{"list"}, a list
      of p-values for a number of randomized datasets with the same 
      structure as the original data.}
    \item{\code{repeats}:}{Object of class \code{"numeric"}, specifies
      the number of randomized datasets that will be generated to 
      calculate the false discovery rate.}
    \item{\code{pthresholds}:}{Object of class \code{"numeric"}, these
      are the p-value-thresholds for the selection. The FDR-threshold
      (see above) is transformed into a p-value threshold by 
      determining how many elements can be selected without exceeding 
      the given threshold of false positives. Since this is done for 
      each annotation dataset this holds a vector of thresholds.}
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterSignif-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterSignif"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterSignif"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterSignifFDR")}:
      interactive setup of the class. You can set the FDR threshold 
      here.}
    \item{setup}{\code{signature(object = "clusterSignifFDR")}:
      returns the configuration of the object as a list. This list can
      be used for the non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "clusterSignifFDR")}:
      non-interactive setup of the class. You need to provide a list
      that contains the necessary settings for the class. }
    \item{execute}{\code{signature(object = "clusterSignifFDR")}:
      selects as many annotation terms as possible without exceeding 
      the specified FDR. }
    \item{reset}{\code{signature(object = "clusterSignifFDR")}:
      resets the results of this class so that the selection process can
      be run again. }
    \item{print}{\code{signature(object = "clusterSignifFDR")}:
      This function prints some basic information about the content of
      this object. If the object has been executed, it will show the
      number of identified annotation terms. }
  }
}

\details{
  The class provides a wrapper around the \code{randomizeTree},
  \code{mergeAnno}, and \code{selectAnnoStats} function. Please read the
  corresponding documentation for further details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{selectAnnoStats}},
  \code{\link{randomizeTree}},
  \code{\link{mergeAnno}},
  \code{\link{goCluster-class}},
  \code{\link{clusterSignif-class}},
  \code{\link{clusterModule-class}}
}

\examples{

## Load a small test dataset
data(benomylsetupsmall)

## Create an emty goCluster object
test <- new("goCluster")

## The "benomylsetupsmall" configuration select FDR selection of
## annotation terms
benomylsetupsmall$classsign

## But we need to select a slightly higher threshold in order
## to find some significant annotation in this very reduced
## dataset
benomylsetupsmall$sign$threshold <- 0.2

## Assign the configuration to the object and directly execute it
execute(test) <- benomylsetupsmall

## These are the selected annotation terms
test@sign@selection

}

\keyword{classes}

