\name{clusterVisualHclust-class}

\docType{class}

\alias{clusterVisualHclust-class}
\alias{display,clusterVisualHclust-method}
\alias{print,clusterVisualHclust-method}
\alias{config,clusterVisualHclust-method}
\alias{execute,clusterVisualHclust-method}
\alias{reset,clusterVisualHclust-method}
\alias{setup<-,clusterVisualHclust-method}
\alias{setup,clusterVisualHclust-method}

\title{Class "clusterVisualHclust" prepares a visualization for a
  dataset that has been clustered with hierarchical clustering.}

\description{
  This class can be used in order to visualize annotation terms that
  have been found as overrepresented in clusters identified with a
  hierarchical clustering. These annotation terms are displayed
  alongside the hierarchical clustering result.
}

\section{Slots}{
  \describe{
    \item{\code{prepared}:}{Object of class \code{"list"}, the number of
      vectors stored in this list corresponds to the number of
      annotations analyzed. Each vector contains the same number of
      items as there are nodes in the tree of the clustering (number of
      genes - 1). The order of appearence corresponds to the ordering of
      the dendrogram so that the sorted dendrogram and the annotation
      terms can be put alongside each other.}
    
  Additional slots are described in the documentation of the
  \code{\link{clusterVisual-class}} and \code{\link{clusterModule-class}}.
  }
}

\section{Extends}{
Class \code{"clusterVisual"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterVisual"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterVisualHclust")}:
      interactive setup of the class. There are no options that you can
      set on this class.}
    \item{setup}{\code{signature(object = "clusterVisualHclust")}:
      returns the configuration of the object as a list. Since there are
      no options to this class, this is always an empty list. }
    \item{setup<-}{\code{signature(object = "clusterVisualHclust")}:
      non-interactive setup of the class. Not necessary since this class
      has no options.}
    \item{execute}{\code{signature(object = "clusterVisualHclust")}:
      prepares the selected annotation terms for the visualization. }
    \item{reset}{\code{signature(object = "clusterVisualHclust")}:
      resets the results of this class so that the analysis can be run
      again. }
    \item{display}{\code{signature(object = "clusterVisualHclust")}:
      generates the actual graphic for this object. }
    \item{print}{\code{signature(x = "clusterVisualHclust")}: prints
      generic information  about the object. }
  }
}

\details{
  The class provides a wrapper around the
  \code{prepareAxis}-function. Please read the corresponding
  documentation for further details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}


\seealso{
  \code{\link{prepareAxis}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterVisual-class}}
}

\examples{

set.seed(1000)

data(benomylsetupsmall)

benomylsetupsmall$classalgo <- "clusterAlgorithmHclust"
benomylsetupsmall$algo$method   <- "complete"
benomylsetupsmall$algo$distance <- "euclidean"

benomylsetupsmall$classvisu <- "clusterVisualHclust"

a <- new("goCluster")

execute(a) <- benomylsetupsmall

if(interactive()){
## This example can only be run in an interactive mode

## This plot shows only one labeled region since the 
## loaded dataset has been reduced to only 100 genes. 
## Try the same with the full dataset
display(a, selection = 1)
}

}

\keyword{classes}
