\name{clusterVisualHeatmap-class}

\docType{class}

\alias{clusterVisualHeatmap-class}

\alias{config,clusterVisualHeatmap-method}
\alias{execute,clusterVisualHeatmap-method}
\alias{reset,clusterVisualHeatmap-method}
\alias{setup<-,clusterVisualHeatmap-method}
\alias{setup,clusterVisualHeatmap-method}
\alias{display,clusterVisualHeatmap-method}
\alias{print,clusterVisualHeatmap-method}

\title{Class "clusterVisualHeatmap", prepares a goCluster analysis for
  visualization. }

\description{
  The class will prepare the \code{goCluster}-result for visualization.
}

\section{Slots}{
  \describe{
    \item{\code{prepared}:}{Object of class \code{"list"}, matches the
      "tree" structure of the annotation term selection from the
      significance analysis. But instead of a single annotation term
      each node holds a combination of the annotation term, the genes
      that were responsible for the selection of this annotation term and
      the expression values of these genes. }
  }
    
  Additional slots are described in the documentation of the
  \code{\link{clusterVisual-class}} and \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterVisual"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterVisual"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterVisualHeatmap")}:
      interactive setup of the class. There are no options that you can
      set on this class.}
    \item{setup}{\code{signature(object = "clusterVisualHeatmap")}:
      returns the configuration of the object as a list. Since there are
      no options to this class, this is always an empty list. }
    \item{setup<-}{\code{signature(object = "clusterVisualHeatmap")}:
      non-interactive setup of the class. Not necessary since this class
      has no options.}
    \item{execute}{\code{signature(object = "clusterVisualHeatmap")}:
      prepares the selected annotation terms for the visualization. }
    \item{reset}{\code{signature(object = "clusterVisualHeatmap")}:
      resets the results of this class so that the analysis can be run
      again. }
    \item{display}{\code{signature(object = "clusterVisualHeatmap")}:
      generates the actual graphic for this object. }
    \item{print}{\code{signature(x = "clusterVisualHeatmap")}: prints
      generic information  about the object. }
  }
}

\details{
  The class provides a wrapper around the
  \code{prepareHeatmap}-function. Please read the corresponding
  documentation for further details.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{prepareHeatmap}},
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterVisual-class}}
}

\examples{

set.seed(1000)

data(benomylsetupsmall)

benomylsetupsmall$classvisu <- "clusterVisualHeatmap"

a <- new("goCluster")

execute(a) <- benomylsetupsmall

if(interactive()){
## This example can only be run in an interactive mode

## This plot shows only four genes since the loaded dataset
## has been reduced to only 100 genes. Try the same with
## the full dataset
display(a, selection = "GO:0003735")
}
}


\keyword{classes}
