\name{clusterVisualNone-class}

\docType{class}

\alias{clusterVisualNone-class}

\alias{config,clusterVisualNone-method}
\alias{execute,clusterVisualNone-method}
\alias{reset,clusterVisualNone-method}
\alias{setup,clusterVisualNone-method}
\alias{setup<-,clusterVisualNone-method}
\alias{display,clusterVisualNone-method}
\alias{print,clusterVisualNone-method}

\title{Class "clusterVisualNone", a placeholder for the goCluster 
visualization methods }

\description{ The class can be used to avoid specifying a
visualization method when performing an analysis with \code{goCluster}. 
}

\section{Slots}{
  All slots are described in the documentation for the
  \code{\link{clusterModule-class}}.
}

\section{Extends}{
Class \code{"clusterVisual"}, directly.
Class \code{"clusterModule"}, by class \code{"clusterVisual"}.
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "clusterVisualNone")}: The 
      class has no parameters. This method does not result in any
      action.}
    \item{execute}{\code{signature(object = "clusterVisualNone")}: The 
      class has no executable function defined and will do nothing. }
    \item{setup}{\code{signature(object = "clusterVisualNone")}: The 
      class has no parameters. This method returns an empty list. }
    \item{setup<-}{\code{signature(object = "clusterVisualNone")}: The 
      class has no parameters. This method does not result in any
      action. }
    \item{reset}{\code{signature(object = "clusterVisualNone")}:
      resets the results of this class so that the analysis can be run
      again. }
    \item{display}{\code{signature(object = "clusterVisualNone")}:
      generates the actual graphic for this object. }
    \item{print}{\code{signature(x = "clusterVisualNone")}: prints
      generic information about the object. }
  }
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}


\seealso{
  \code{\link{goCluster-class}},
  \code{\link{clusterModule-class}},
  \code{\link{clusterVisual-class}}
}

\examples{

set.seed(1000)

data(benomylsetupsmall)

a <- new("goCluster")

## This will result in an object without visualization
execute(a) <- benomylsetupsmall

## We can choose and add the visualization method afterwards

## Create the visualization method
b <- new("clusterVisualHeatmap")

## Assign the new method to the old goCluster object
a@visu <- b

## Prepare the visualization
a@visu <- execute(a@visu, a)

if(interactive()){
## This example can only be run in an interactive mode

## This plot shows only four genes since the loaded dataset
## has been reduced to only 100 genes. Try the same with
## the full dataset
display(a, selection = "GO:0003735")
}
}

\keyword{classes}
