\name{clusterclara}

\alias{clusterclara}

\title{ Clusters a dataset with the clara function }

\description{
  This function is used in the goCluster framework to cluster a dataset
  with the clara function.
}

\usage{
clusterclara(dataset, clusters, distance = "euclidean", repeats = 1, fixed = TRUE)
}

\arguments{
  \item{dataset}{ The dataset to be clustered. This has to be a matrix. }
  \item{clusters}{ This specifies the number of clusters that the dataset
    should be partitioned into. }
  \item{distance}{ The distance metric that is going to be used by clara. }
  \item{fixed}{ This option determines whether the analysis should start
    with a fixed random seed or with a truely random seed. A fixed seed
    leads to a stable result but does not represent the inherent
    variability of the clustering approach. }
  \item{repeats}{ In case clara clusters without a fixed seed it may be
    useful to repeat the clustering in order to get an impression of the 
    variability of the clustering result. This option specifies the
    number of repeats. }
}

\details{
  Clara clustering will partition the dataset of the parent object into
  the number of clusters specified by the user. 
  Clara is very similar to PAM (partitioning around medoids) but has
  been adapted to large datasets. It has the same advantages as PAM
  concerning the judgement of quality for the resulting clusters but it
  lacks a deterministic outcome.  Therefore it is significantly faster
  than PAM. You may request a stable result by using a fixed seed, but
  this can convey an incorrect impression of the stability of the
  result. Alternatively \code{clusterclara} can repeat the clustering though
  that will partially defeat the gain in speed over PAM.
  
}

\value{
  A "tree" (list of lists) of clusters. The first level will
  hold as many list elements as the number of times the clustering
  has been repeated. Each of these elements holds a number of lists
  equal to the number of clusters requested .Each of node on this second
  level hold the unique ids of the genes in the cluster.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAlgorithmClara-class}}
  \code{\link[cluster]{clara}}
} 

\examples{
require(cluster)

## Get the benomyl setup
data(benomylsetup)

## Extract a fraction of the dataset
benomyldata <- benomylsetup$data$dataset[1:200,]
benomylids  <- benomylsetup$data$uniqueid[1:200]

## Cluster the dataset
clusterclara(exprs(benomyldata), 4)

}

\keyword{ utilities }
