\name{clusterhclust}

\alias{clusterhclust}

\title{ Clusters a dataset using hierarchical clustering }

\description{
  This function is used by \code{goCluster} to cluster a dataset
  with the \code{hclust} function.
}

\usage{
clusterhclust(
dataset,
method = "complete",
distance = "euclidean"
)
}

\arguments{
  \item{dataset}{ The dataset to be clustered. This has to be a matrix. }
  \item{method}{ The clustering method that is going to be used by \code{hclust}. }
  \item{distance}{ The distance metric that is going to be used by \code{hclust}. }
}

\details{
  Hierarchical clustering will generate a tree that defines gene
  subgroups based on similarity. Each branchpoint in the tree denotes the
  splitting of a larger gene group into two smaller groups. The function
  converts the hclust format into a tree of lists that is being returned
  to the user.
}

\value{
  The result represent the \code{hclust}-tree as a list of lists. The
  terminal nodes of the tree are character vectors holding the unique
  ids of the genes in the cluster.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAlgorithmHclust-class}},
  \code{\link{hclust}}
} 

\examples{
## Get the benomyl setup
data(benomylsetup)

## Extract a fraction of the dataset
benomyldata <- benomylsetup$data$dataset[1:200,]
benomylids  <- benomylsetup$data$uniqueid[1:200]

## Cluster the dataset
clusterhclust(exprs(benomyldata))

}

\keyword{ utilities }
