\name{clusterkmeans}

\alias{clusterkmeans}

\title{ Clusters a dataset with the kmeans function }

\description{
  This function is used in the goCluster framework to cluster a dataset
  with the kmeans function.
}
\usage{
clusterkmeans(dataset, clusters, repeats)
}

\arguments{
  \item{dataset}{ The dataset to be clustered. This has to be a matrix. }
  \item{clusters}{ This specifies the number of clusters that the dataset
    should be partitioned into. }
  \item{repeats}{ It may be useful to repeat the clustering in order to
    get an impression of the variability of the clustering result. This
    option specifies the number of repeats. }
}

\details{
  Kmeans clustering will partition the dataset of the parent object into
  the number of clusters specified by the user. This will be repeated as
  often as specified in the repeats option.
  The class will return a list of groups that can subsequently be
  analyzed by statistical means for any enrichment of functional
  categories.
  The repetition of clustering is included since kmeans is no
  deterministic procedure. Depending on the initialization conditions
  the result may vary slightly. Thus repeating the process yields an
  average.
}

\value{
  A "tree" (list of lists) of clusters. The first level will
  hold as many list elements as the number of times the clustering
  has been repeated. Each of these elements holds a number of lists
  equal to the number of clusters requested .Each of node on this second
  level hold the unique ids of the genes in the cluster.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAlgorithmClara-class}}
  \code{\link[cluster]{clara}}
} 

\examples{
require(cclust)

## Get the benomyl setup
data(benomylsetup)

## Extract a fraction of the dataset
benomyldata <- benomylsetup$data$dataset[1:200,]
benomylids  <- benomylsetup$data$uniqueid[1:200]

## Cluster the dataset
clusterkmeans(exprs(benomyldata), 4, 2)

}

\keyword{ utilities }
