\name{clusterpam}

\alias{clusterpam}

\title{ Clusters a dataset with the pam function }

\description{
  This function is used in the goCluster framework to cluster a dataset
  with the pam function.
}

\usage{
clusterpam(dataset, clusters, distance = "euclidian")
}

\arguments{
  \item{dataset}{ The dataset to be clustered. This has to be a matrix. }
  \item{clusters}{ This specifies the number of clusters that the dataset
    should be partitioned into. }
  \item{distance}{ The distance metric that is going to be used by pam. }
}

\details{
  PAM clustering will partition the dataset of the parent object into
  the number of clusters specified by the user. This list of groups can
  subsequently be analyzed by statistical means for any enrichment of functional
  categories.
  PAM is considered to be more stable than K-means clustering and offers
  better techniques for validating the results e.g. the stability of clusters.
  It yields a deterministic outcome, but might take very long on large
  datasets (see \code{clara}).
}

\value{
  A "tree" (list of lists) of clusters. The first level will
  hold as many list elements as the number of times the clustering
  has been repeated. Each of these elements holds a number of lists
  equal to the number of clusters requested. Each of node on this second
  level hold the unique ids of the genes in the cluster.
}

\examples{
require(cluster)

## Get the benomyl setup
data(benomylsetup)

## Extract a fraction of the dataset
benomyldata <- benomylsetup$data$dataset[1:200,]
benomylids  <- benomylsetup$data$uniqueid[1:200]

## Cluster the dataset
clusterpam(exprs(benomyldata), 4)

}

\keyword{ utilities }
