\name{goCluster-class}

\docType{class}

\alias{goCluster-class}
\alias{config,goCluster-method}
\alias{reset,goCluster-method}
\alias{run<-,goCluster-method}
\alias{run,goCluster-method}
\alias{setup<-,goCluster-method}
\alias{setup,goCluster-method}
\alias{print,goCluster-method}
\alias{display,goCluster-method}
\alias{goClusterTk}

\title{Class "goCluster", a class for combining clustering results with
  functional annotation}

\description{  This class provides a skeleton for the linkage of
  clustering results with statistical analysis of functional
  annotation. }

\section{Objects from the Class}{
Objects can be created by calls of the form \code{new("goCluster")}.
}

\section{Slots}{
  \describe{
    \item{\code{data}:}{Object of class \code{"clusterData"}, the
      dataset that is going to be clustered.}
    \item{\code{algo}:}{Object of class \code{"clusterAlgorithm"}, the
      algorithm that is used for clustering.}
    \item{\code{sign}:}{Object of class \code{"clusterSignif"}, the
      function to estimate the significance of clusters based on the
      analysis of the associated annotation data.}
    \item{\code{visu}:}{Object of class \code{"clusterVisual"}, which
      provides methods to visualize of the results.}
  }
}

\section{Methods}{
  \describe{
    \item{config}{\code{signature(object = "goCluster")}: interactive
      setup of the class. }
    \item{setup}{\code{signature(object = "goCluster")}: returns the
      configuration as a list. This list can again be used for the
      non-interactive setup of the class. }
    \item{setup<-}{\code{signature(object = "goCluster")}:
      non-interactive setup of the class. The option are specified using
      a list. }
    \item{run}{\code{signature(object = "goCluster")}: run goCluster as
      specified during setup. }
    \item{run<-}{\code{signature(object = "goCluster")}: run goCluster
      with the setting given as value to the assignment. }
    \item{reset}{\code{signature(object = "goCluster")}: reset all
      results that were obtained during the last run of goCluster. }
    \item{display}{\code{signature(object = "goCluster")}: calls the
      display function of the clusterVisual object defined for the
      goCluster anaylsis. }
    \item{print}{\code{signature(object = "goCluster")}: calls the print
      function on each of the defined sub-objects. The output is being
      concatenated and returned to the user.}
  }
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAnnotation-class}},
  \code{\link{clusterData-class}},
  \code{\link{clusterAlgorithm-class}},
  \code{\link{clusterStatistic-class}},
  \code{\link{clusterSignif-class}},
  \code{\link{clusterVisual-class}},
  \code{\link{config}},
  \code{\link{setup}},
  \code{\link{setup<-}},
  \code{\link{execute}},
  \code{\link{execute<-}},
  \code{\link{reset}}
.} 

\examples{
## Load the configuration and create a new
## goCluster object
data(benomylsetup)
test <- new("goCluster")

## Perform the analysis by using the execute<- method
execute(test) <- benomylsetup

}

\keyword{classes}

