\name{prepareCHRannotation}

\alias{prepareCHRannotation}

\title{ A function to prepare the gene localization for subsequent
  statistical analysis }
\description{
  This function builds an association table between a given list of
  genes and the chromosome they can be found on. 
}
\usage{
prepareCHRannotation(uniqueID, annBuilderPkg, chromosomes = NULL, trueID = NULL)
}

\arguments{
  \item{uniqueID}{ The unique ID that should be associated with the gene
    ontology annotation. }
  \item{annBuilderPkg}{ The AnnBuilder package that provides the basis
    for retrieving the annotation information. }
  \item{chromosomes}{ The output is restricted to genes lying on these
    chromosomes. }
  \item{trueID}{ The true ID specifies the type of ID that the
    chromosome information has been linked to (e.g. Locus Link). If this
    ID differs from the the type of \code{uniqueID} this has to be
    specified so that the IDs are converted accordingly. The option
    needs to match the name of the AnnBuilder package environment
    (without the prefix) that provides the conversion information. }
}

\details{
  The class retrieves information about the chromosome each gene lies on
  from a given AnnBuilder annotation package and converts that information
  into a format useful for the subsequent analysis.
  The class removes all genes not present in the in the dataset,
  eliminates any duplicate entries (respecting the true ID if specified)
  and can remove any chromosomes that should not be included into analysis.
}

\value{
  A composite list of the (possibly converted) unique ID and the
  association table.

  \item{annotations }{The association table linking the genes with the
    chromosome they lie on. }
  \item{uniqueid }{Either a copy of the original unique identifiers or a
  converted copy that matches the original vector in length but
  specifies the new gene ID for each gene. }
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAnnotationChromosome-abp-class}}
} 

\examples{
prepareCHRannotation(c("YGL213C", "YGL215W", "YGL216W", "YGL218W",
"YGL219C", "YGL220W", "YGL221C", "YGL222C", "YGL223C", "YGL224C",
"YGL225W"), "YEAST")
}

\keyword{ utilities }
