\name{prepareGOannotation}

\alias{prepareGOannotation}

\title{A function to prepare the gene ontology annotation for subsequent
  statistical analysis}

\description{
  This function builds an association table between a given list of
  genes and their corresponding gene ontology annotations. 
}

\usage{
prepareGOannotation(uniqueID,
annBuilderPkg,
ontologies = ONTOLOGIES,
evidence = EVIDENCECODES,
trueID = NULL)
}

\arguments{
  \item{uniqueID}{ The unique ID that should be associated with the gene
  ontology annotation. }
  \item{annBuilderPkg}{ The AnnBuilder package that provides the basis
    for retrieving the annotation information. }
  \item{ontologies}{ The ontologies that should be used. This has to be
    a character vector that contains one or more of the strings "MF",
    "BP", and/or "CC". }
  \item{evidence}{ This character vector should contain the
    abbreviations for acceptable evidence codes. Please see the variable
    EVIDENCECODES for possible choices. The complete vector with all
    evidence codes is the default for the function. }
  \item{trueID}{ The true ID specifies the type of ID that the gene
    ontology information has been linked to (e.g. Locus Link). If this
    ID differs from the the type of \code{uniqueID} this has to be
    specified so that the IDs are converted accordingly. The option
    needs to match the name of the AnnBuilder package environment
    (without the prefix) that provides the conversion information. }
}
\details{
  The gene ontology is organized as a hierarchical tree of terms
  with a parent-child relationship. By associating a gene with a term of
  this ontology the gene is implicitely linked with all parents of
  the term. In order to render the annotation of two gene lists
  comparable it is important to take this relationship into account.
  
  The \code{prepareGOannotation} function assembles a complete list of
  gene <-> ontology associations based on the gene ontology
  annotation. Duplicate genes are removed from the resulting table. This
  removal should be based on the identifiers the gene ontology
  information is linked to (e.g. Lokus Link) and it is possible to
  specify this central ID by setting the \code{trueid} option.
}

\value{
  A composite list of the (possibly converted) unique ID and the
  association table.

  \item{annotations }{The association table linking the genes with gene
    ontology terms. Each gene can be linked to multiple GO entries and
    vice versa. }
  \item{uniqueid }{Either a copy of the original unique identifiers or a
  converted copy that matches the original vector in length but
  specifies the new gene ID for each gene. }
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterAnnotationGO-abp-class}}
} 

\examples{
prepareGOannotation(c("YGL213C", "YGL215W", "YGL216W", "YGL218W",
"YGL219C", "YGL220W", "YGL221C", "YGL222C", "YGL223C", "YGL224C",
"YGL225W"), "YEAST")
}

\keyword{ utilities }% at least one, from doc/KEYWORDS
