\name{prepareHeatmap}

\alias{prepareHeatmap}

\title{A function to reformat a goCluster result for graphical representation}

\description{
  The function will combine a selection of annotation terms with a
  clustering result of the dataset in order to identify the genes that
  led to the identification of each annotation term. For each annotation
  term selected, the class will assemble an element that holds the
  annotation term, the associated p-value, the corresponding genes, and
  the expression data of these genes. This can then be converted to a
  nice heatmap representation for the annotation term.
}

\usage{
prepareHeatmap(X, Clusters, Annoset, Dataset, ID)
}

\arguments{
  \item{X}{ The tree of selected annotation terms. }
  \item{Clusters}{ The tree of clusters. The tree structure must match
    the structure of the  }
  \item{Annoset}{ The different annotations that were used in the
    analysis. }
  \item{Dataset}{ The original dataset. }
  \item{ID}{ The unique id of each element in the dataset. It bridges
    the element index in the clustering result and the annotation data. }
}

\value{
  A list of lists that has the same tree structure as the input
  tree. Instead of annotation terms each node holds a combination of
  annotation term, p-value, genes responsible for the selection of the
  annotation term as well as the expression values of these genes.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterVisualHeatmap-class}}
}

\examples{

set.seed(1000)

data(benomylsetupsmall)

benomylsetupsmall$classvisu <- "clusterVisualHeatmap"

a <- new("goCluster")

execute(a) <- benomylsetupsmall

## This list shows only a few genes since the loaded dataset
## has been reduced to only 100 genes. Try the same with
## the full dataset (benomylsetup)
prepareHeatmap(a@sign@selection,
               a@algo@clusterset,
               a@data@anno@annoset,
               exprs(a@data@dataset),
               a@data@anno@uniqueid)
}

\keyword{ utilities }
