\name{reset-methods}

\docType{methods}

\alias{reset}

\title{Reset a goCluster-module}

\description{
  This method can be used on all \code{goCluster}-objects and will
  delete any intermediate results. This allows to redo the analysis
  after changing the configuration of the \code{goCluster}-object.
}

\section{Methods}{
  \describe{
    \item{object = "clusterModule"}{ The method is only defined for
      the \code{clusterModule}-class. But it is available for any
      \code{goCluster}-object since all classes made available by the
      \code{goCluster}-package extend the basic
      \code{clusterModule}-class.
    }
  }
}

\seealso{
  \code{\link{clusterModule-class}}.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\examples{

## Load small a test dataset
data(benomylsetupsmall)

## Create an empty goCluster object
test <- new("goCluster")

## Assign the configuration to the object and directly execute it
execute(test) <- benomylsetupsmall

## Change the configuration
## (Number of clusters are changed to 3)
test@algo@clusters <- 3

## After that it should not be executable again
failure <- try(execute(test))
if (!inherits(failure, "try-error")) stop("The goCluster object should not be executable a second time!")

## Reset the object
test <- reset(test)
## This should run fine
test <- execute(test)

  }

\keyword{methods}
