\name{selectCore}

\alias{selectCore}
\alias{selectCorePlain}
\alias{selectCoreTk}

\title{A menu function}
\description{
  The function generates a generic menu that will return the choice
  of the user.
} 

\usage{
selectCore(message,
convert = function(X) X,
check = function(X) TRUE,
options = NULL,
optflag = TRUE,
error = function(X) return("Invalid choice!"),
...
)
selectCorePlain(message,
convert = function(X) X,
check = function(X) TRUE,
options = NULL,
optflag = TRUE,
error = function(X) return("Invalid choice!"),
...
)
selectCoreTk(message,
convert = function(X) X,
check = function(X) TRUE,
options = NULL,
optflag = TRUE,
error = function(X) return("Invalid choice!"),
...
)
}

\arguments{
  \item{message}{The informational message that will be shown together
    with the menu.}
  \item{convert}{A function that converts the user input to a desired
    format or class type.}
  \item{check}{A function that checks the user input for validity.}
  \item{options}{The available options as character vector, if any.}
  \item{optflag}{Is the user allowed to select several options or only one?}
  \item{error}{The function that should be executed in case of an
    error. This should deliver a message that is useful to the user.}
  \item{\dots}{ Additional arguments for the convert, check and error
    functions. }
}

\details{
  \code{selectCore} is a function that provides a generic menu. This
  can either be a simple textual menu or a graphical
  version depending on the setting of the option
  \code{goCluster.useTk}. You can use \code{option(goCluster.useTk=1)}
  to activate the graphical menu. \code{selectCore} will then dispatch
  the function call to the Tk version of the function instead of the
  textual version. The textual menu is the default. The function needs a
  message that should be displayed to the user, a function to convert
  the user input to a desired format and another function to check the
  validity of the user input. Finally a set of options that should be
  displayed to the user as a numbered list can be specified as a
  character vector. If \code{convert} is not specified, the user input
  will be used as given (string format) and if \code{check} is left
  unspecified, the check will always return TRUE. 
}

\value{
  The choice of the user in the format returned by the convert function.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{selectOption}},
  \code{\link{selectDouble}},
  \code{\link{selectNumber}}.
}

\examples{
if(interactive()){
## This example can only be run in an interactive mode
option(goCluster.useTk=0)

selectCore("Please choose a number between 0 and 10",convert=function(X) as.integer(X), check=function(X) (X > 0 & X < 10))

option(goCluster.useTk=1)

selectCore("Please choose a number between 0 and 10",convert=function(X) as.integer(X), check=function(X) (X > 0 & X < 10))
}
}

\keyword{utilities}
