\name{selectStats}

\alias{selectStats}

\title{ Selects relevant annotation terms }

\description{
  This function removes all annotation terms with a p-value higher than
  the given threshold from the given tree. 
}

\usage{
selectStats(X, threshold)
}

\arguments{
  \item{X}{ The tree of annotation terms as retrieved by the statistical
  analysis function (e.g. evalClusterHyper)}
  \item{threshold}{ The selection threshold for the p-values. }
}

\details{
  The function will walk through all nodes of the tree specified as X
  and removes all annotation terms with a p-value lower than the given
  threshold. The resulting tree will have the same structure as before
  but it can contain nodes that  are empty. This function does perform
  no correction for multiple testing whatsoever and should be used with
  caution. }
}

\value{
  A reduced tree with annotation elements having a "significant" p-value.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterSignifBase-class}}
} 

\examples{

set.seed(1000)

data(benomylsetupsmall)

a <- new("goCluster")

execute(a) <- benomylsetupsmall

## The statistics are saved in the "statset" slot of
## the "stat" object that is itself a child of the "sign"
## object of a "goCluster" object
## We select all items with a p-value below 0.05 here. 
selectStats(a@sign@stat@statset,0.05)

}

\keyword{utilities}
