\name{selectStatsBonferroni}

\alias{selectStatsBonferroni}

\title{ Performs Bonferroni correction and subsequently selects relevant
  annotation terms.}

\description{
  This function corrects the p-values for the annotation terms in the
  given tree by taking the total number of elements in the tree into
  account. It removes all annotation terms with a p-value higher than
  the given threshold after the values have been corrected. 
}

\usage{
selectStatsBonferroni(X, threshold, tests)
}

\arguments{
  \item{X}{ The tree of annotation terms as retrieved by the statistical
  analysis function (e.g. evalClusterHyper)}
  \item{threshold}{ The selection threshold for the p-values. }
  \item{tests}{ The number of annotation terms tested. }
}

\details{
  The function will walk through all nodes of the tree specified as X
  and remove all annotation terms with a p-value lower than the given
  threshold divided by the number of tests (Bonferroni correction). The
  resulting tree will have the same structure as before but it can
  contain nodes that are empty.
}

\value{
  A reduced tree with annotation elements having a significant p-value.
  This type of multiple testing correction assumes that the annotation
  terms are independant and should thus not be used for annotation data
  sets as for exmple the gene ontology.
}

\author{Gunnar Wrobel, \url{work@gunnarwrobel.de}, \url{http://www.gunnarwrobel.de}.}

\seealso{
  \code{\link{clusterSignifBonferroni-class}}
} 

\examples{

set.seed(1000)

data(benomylsetupsmall)

a <- new("goCluster")

execute(a) <- benomylsetupsmall

## The statistics are saved in the "statset" slot of
## the "stat" object that is itself a child of the "sign"
## object of a "goCluster" object
## We select all items with a p-value below 0.05 after
## Bonferroni correction. 
selectStatsBonferroni(a@sign@stat@statset,0.05,length(unlist(a@sign@stat@statset)))

}

\keyword{utilities}
